@@ -5,16 +5,20 @@ UglifyJS.optimize = function(code, opts){
   ast.figure_out_scope();
   ast = ast.transform(compressor);
   return ast.print_to_string();
-}
+};
 
 UglifyJS.reformat = function(code, opts){
   var ast = UglifyJS.parse(code);
   var stream = UglifyJS.OutputStream(opts);
-  var code = ast.print(stream);
+  ast.print(stream);
   return stream.toString();
-}
+};
 
 jshint.run = function(a,b,c) {
   var err = jshint.JSHINT(a,b,c);
   return err ? null : jshint.JSHINT.errors;
-}
+};
+
+esprima.parse_to_json = function(str, config){
+  return JSON.stringify(esprima.parseScript(str, config), null, 2);
+};
